Stemming
========

Porter Stemmer
--------------

.. py:function:: porter_stem(s)

    Reduce the string s to its stem using the common Porter stemmer.

Stemming is the process of reducing a word to its root form, for example 'stemmed' to 'stem'.

Martin Porter's algorithm is a common algorithm used for stemming that works for many purposes.

See the `official homepage for the Porter Stemming Algorithm <http://tartarus.org/martin/PorterStemmer/>`_ for more details.
